ActorImage class abstract

ActorImage

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ActorImage([void updates(ActorImageBuilder b)])
factory

Properties

createdAt DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
path String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
no setter
width int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ActorImageBuilder)) ActorImage
Rebuilds the instance.
inherited
toBuilder() ActorImageBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ActorImage>
no setter