AddVideoPlaylistVideoRequestVideoId class abstract

Video to add in the playlist

Annotations
  • @BuiltValue.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
oneOf OneOf
One Of Uuid, int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AddVideoPlaylistVideoRequestVideoIdBuilder)) AddVideoPlaylistVideoRequestVideoId
Rebuilds the instance.
inherited
toBuilder() AddVideoPlaylistVideoRequestVideoIdBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AddVideoPlaylistVideoRequestVideoId>
no setter