FileStorage class

Inheritance
  • Object
  • EnumClass
  • FileStorage

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<FileStorage>
no setter
values → BuiltSet<FileStorage>
no setter

Static Methods

valueOf(String name) FileStorage

Constants

number0 → const FileStorage
The file storage type: - 0 File system - 1 Object storage
number1 → const FileStorage
The file storage type: - 0 File system - 1 Object storage