LiveVideoUpdate class abstract

LiveVideoUpdate

Properties:

Annotations
  • @BuiltValue.new()

Constructors

LiveVideoUpdate([void updates(LiveVideoUpdateBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
latencyMode LiveVideoLatencyMode?
no setter
permanentLive bool?
User can stream multiple times in a permanent live
no setter
replaySettings LiveVideoReplaySettings?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveReplay bool?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LiveVideoUpdateBuilder)) LiveVideoUpdate
Rebuilds the instance.
inherited
toBuilder() LiveVideoUpdateBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<LiveVideoUpdate>
no setter