Notification class abstract

Notification

Properties:

  • id
  • type - Notification type, following the UserNotificationType enum: - 1 NEW_VIDEO_FROM_SUBSCRIPTION - 2 NEW_COMMENT_ON_MY_VIDEO - 3 NEW_ABUSE_FOR_MODERATORS - 4 BLACKLIST_ON_MY_VIDEO - 5 UNBLACKLIST_ON_MY_VIDEO - 6 MY_VIDEO_PUBLISHED - 7 MY_VIDEO_IMPORT_SUCCESS - 8 MY_VIDEO_IMPORT_ERROR - 9 NEW_USER_REGISTRATION - 10 NEW_FOLLOW - 11 COMMENT_MENTION - 12 VIDEO_AUTO_BLACKLIST_FOR_MODERATORS - 13 NEW_INSTANCE_FOLLOWER - 14 AUTO_INSTANCE_FOLLOWING - 15 ABUSE_STATE_CHANGE - 16 ABUSE_NEW_MESSAGE - 17 NEW_PLUGIN_VERSION - 18 NEW_PEERTUBE_VERSION - 19 MY_VIDEO_STUDIO_EDITION_FINISHED - 20 NEW_USER_REGISTRATION_REQUEST - 21 NEW_LIVE_FROM_SUBSCRIPTION
  • read
  • video
  • videoImport
  • comment
  • videoAbuse
  • videoBlacklist
  • account
  • actorFollow
  • createdAt
  • updatedAt
Annotations
  • @BuiltValue.new()

Constructors

Notification([void updates(NotificationBuilder b)])
factory

Properties

account ActorInfo?
no setter
actorFollow NotificationActorFollow?
no setter
comment NotificationComment?
no setter
createdAt DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
id int?
no setter
read bool?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
Notification type, following the UserNotificationType enum: - 1 NEW_VIDEO_FROM_SUBSCRIPTION - 2 NEW_COMMENT_ON_MY_VIDEO - 3 NEW_ABUSE_FOR_MODERATORS - 4 BLACKLIST_ON_MY_VIDEO - 5 UNBLACKLIST_ON_MY_VIDEO - 6 MY_VIDEO_PUBLISHED - 7 MY_VIDEO_IMPORT_SUCCESS - 8 MY_VIDEO_IMPORT_ERROR - 9 NEW_USER_REGISTRATION - 10 NEW_FOLLOW - 11 COMMENT_MENTION - 12 VIDEO_AUTO_BLACKLIST_FOR_MODERATORS - 13 NEW_INSTANCE_FOLLOWER - 14 AUTO_INSTANCE_FOLLOWING - 15 ABUSE_STATE_CHANGE - 16 ABUSE_NEW_MESSAGE - 17 NEW_PLUGIN_VERSION - 18 NEW_PEERTUBE_VERSION - 19 MY_VIDEO_STUDIO_EDITION_FINISHED - 20 NEW_USER_REGISTRATION_REQUEST - 21 NEW_LIVE_FROM_SUBSCRIPTION
no setter
updatedAt DateTime?
no setter
video NotificationVideo?
no setter
videoAbuse NotificationVideoAbuse?
no setter
videoBlacklist NotificationVideoAbuse?
no setter
videoImport NotificationVideoImport?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NotificationBuilder)) Notification
Rebuilds the instance.
inherited
toBuilder() NotificationBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Notification>
no setter