NotificationComment class abstract

NotificationComment

Properties:

Annotations
  • @BuiltValue.new()

Constructors

NotificationComment([void updates(NotificationCommentBuilder b)])
factory

Properties

account ActorInfo?
no setter
hashCode int
The hash code for this object.
no setterinherited
heldForReview bool?
no setter
id int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadId int?
no setter
video VideoInfo?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NotificationCommentBuilder)) NotificationComment
Rebuilds the instance.
inherited
toBuilder() NotificationCommentBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NotificationComment>
no setter