RequestTwoFactorResponse class abstract

RequestTwoFactorResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

RequestTwoFactorResponse([void updates(RequestTwoFactorResponseBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
otpRequest RequestTwoFactorResponseOtpRequest?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RequestTwoFactorResponseBuilder)) RequestTwoFactorResponse
Rebuilds the instance.
inherited
toBuilder() RequestTwoFactorResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RequestTwoFactorResponse>
no setter