RunnerJobBuilder class abstract mixin

Implementers

Constructors

RunnerJobBuilder()

Properties

createdAt DateTime?
getter/setter pair
error String?
getter/setter pair
failures int?
getter/setter pair
finishedAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
parent RunnerJobParentBuilder
getter/setter pair
payload RunnerJobPayloadBuilder
getter/setter pair
priority int?
getter/setter pair
progress int?
getter/setter pair
runner RunnerJobRunnerBuilder
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime?
getter/setter pair
state RunnerJobStateConstantBuilder
getter/setter pair
type RunnerJobType?
getter/setter pair
updatedAt DateTime?
getter/setter pair
uuid String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(RunnerJob other) → void
toString() String
A string representation of this object.
inherited
update(void updates(RunnerJobBuilder)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited