ServerConfigCustomTranscoding class abstract

Settings pertaining to transcoding jobs

Properties:

Annotations
  • @BuiltValue.new()

Properties

allowAdditionalExtensions bool?
Allow your users to upload .mkv, .mov, .avi, .wmv, .flv, .f4v, .3g2, .3gp, .mts, m2ts, .mxf, .nut videos
no setter
allowAudioFiles bool?
If a user uploads an audio file, PeerTube will create a video by merging the preview file and the audio file
no setter
concurrency num?
Amount of transcoding jobs to execute in parallel
no setter
enabled bool?
no setter
hashCode int
The hash code for this object.
no setterinherited
hls ServerConfigCustomTranscodingHls?
no setter
originalFile ServerConfigCustomTranscodingOriginalFile?
no setter
profile ServerConfigCustomTranscodingProfileEnum?
New profiles can be added by plugins ; available in core PeerTube: 'default'.
no setter
resolutions ServerConfigCustomTranscodingResolutions?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threads int?
Amount of threads used by ffmpeg for 1 transcoding job
no setter
webVideos ServerConfigCustomTranscodingWebVideos?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ServerConfigCustomTranscodingBuilder)) ServerConfigCustomTranscoding
Rebuilds the instance.
inherited
toBuilder() ServerConfigCustomTranscodingBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ServerConfigCustomTranscoding>
no setter