ServerConfigInstanceBuilder class

Properties

avatars ↔ ListBuilder<ActorImage>
getter/setter pair
banners ↔ ListBuilder<ActorImage>
getter/setter pair
customizations ServerConfigInstanceCustomizationsBuilder
getter/setter pair
defaultClientRoute String?
getter/setter pair
defaultNSFWPolicy String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isNSFW bool?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverCountry String?
getter/setter pair
shortDescription String?
getter/setter pair
social ServerConfigInstanceSocialBuilder
getter/setter pair
support ServerConfigInstanceSupportBuilder
getter/setter pair

Methods

build() ServerConfigInstance
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ServerConfigInstance other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(ServerConfigInstanceBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited