ServerConfigVideoFile class abstract

ServerConfigVideoFile

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ServerConfigVideoFile([void updates(ServerConfigVideoFileBuilder b)])
factory

Properties

extensions → BuiltList<String>?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ServerConfigVideoFileBuilder)) ServerConfigVideoFile
Rebuilds the instance.
inherited
toBuilder() ServerConfigVideoFileBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ServerConfigVideoFile>
no setter