VideoChannelListDataInner class abstract

VideoChannelListDataInner

Properties:

Implemented types
Annotations
  • @BuiltValue.new()

Constructors

VideoChannelListDataInner([void updates(VideoChannelListDataInnerBuilder b)])
factory

Properties

avatars → BuiltList<ActorImage>?
no setterinherited
banners → BuiltList<ActorImage>?
no setterinherited
createdAt DateTime?
no setterinherited
description String?
no setterinherited
displayName String?
editable name of the channel, displayed in its representations
no setterinherited
followersCount int?
number of followers of this actor, as seen by this instance
no setterinherited
followingCount int?
number of actors subscribed to by this actor, as seen by this instance
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
host String?
server on which the actor is resident
no setterinherited
hostRedundancyAllowed bool?
whether this actor's host allows redundancy of its videos
no setterinherited
id int?
no setterinherited
isLocal bool?
no setterinherited
name String?
immutable name of the actor, used to find or mention it
no setterinherited
ownerAccount Account?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
support String?
text shown by default on all videos of this channel, to tell the audience how to support it
no setterinherited
updatedAt DateTime?
no setterinherited
url String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VideoChannelListDataInnerBuilder)) VideoChannelListDataInner
Rebuilds the instance.
inherited
toBuilder() VideoChannelListDataInnerBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VideoChannelListDataInner>
no setter