VideoChannelSyncCreate class abstract

VideoChannelSyncCreate

Properties:

Annotations
  • @BuiltValue.new()

Constructors

VideoChannelSyncCreate([void updates(VideoChannelSyncCreateBuilder b)])
factory

Properties

externalChannelUrl String?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoChannelId int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VideoChannelSyncCreateBuilder)) VideoChannelSyncCreate
Rebuilds the instance.
inherited
toBuilder() VideoChannelSyncCreateBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VideoChannelSyncCreate>
no setter