VideoCommentThreadTree class abstract

VideoCommentThreadTree

Properties:

Annotations
  • @BuiltValue.new()

Constructors

VideoCommentThreadTree([void updates(VideoCommentThreadTreeBuilder b)])
factory

Properties

children → BuiltList<VideoCommentThreadTree>?
no setter
comment VideoComment?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VideoCommentThreadTreeBuilder)) VideoCommentThreadTree
Rebuilds the instance.
inherited
toBuilder() VideoCommentThreadTreeBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VideoCommentThreadTree>
no setter