VideoImport class abstract

VideoImport

Properties:

Annotations
  • @BuiltValue.new()

Constructors

VideoImport([void updates(VideoImportBuilder b)])
factory

Properties

createdAt DateTime?
no setter
error String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id int?
no setter
magnetUri String?
magnet URI allowing to resolve the import's source video
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state VideoImportStateConstant?
no setter
targetUrl String?
remote URL where to find the import's source video
no setter
torrentfile Uint8List?
Torrent file containing only the video file
no setter
torrentName String?
no setter
updatedAt DateTime?
no setter
video Video?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VideoImportBuilder)) VideoImport
Rebuilds the instance.
inherited
toBuilder() VideoImportBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VideoImport>
no setter