VideoImportBuilder class
Constructors
Properties
- createdAt ↔ DateTime?
-
getter/setter pair
- error ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pair
- magnetUri ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ VideoImportStateConstantBuilder
-
getter/setter pair
- targetUrl ↔ String?
-
getter/setter pair
- torrentfile ↔ Uint8List?
-
getter/setter pair
- torrentName ↔ String?
-
getter/setter pair
- updatedAt ↔ DateTime?
-
getter/setter pair
- video ↔ Video?
-
getter/setter pair
Methods
-
build(
) → VideoImport -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
VideoImport other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(VideoImportBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited