MRSSGroupContent class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- MRSSGroupContent([void updates(MRSSGroupContentBuilder b)])
-
factory
Properties
- duration → int?
-
no setter
- fileSize → int?
-
no setter
- framerate → int?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
no setter
- lang → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
no setter
- url → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(MRSSGroupContentBuilder)) → MRSSGroupContent -
Rebuilds the instance.
inherited
-
toBuilder(
) → MRSSGroupContentBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
MRSSGroupContent> -
no setter