MyHistoryApi class
Constructors
-
MyHistoryApi(Dio _dio, Serializers _serializers)
-
const
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apiV1UsersMeHistoryVideosGet({int? start, int? count = 15, String? search, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<VideoListResponse>>
-
List watched videos history
-
apiV1UsersMeHistoryVideosRemovePost({DateTime? beforeDate, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<void>>
-
Clear video history
-
apiV1UsersMeHistoryVideosVideoIdDelete({required int videoId, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<void>>
-
Delete history element
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited