Notification class abstract
Notification
Properties:
- id
- type - Notification type, following the
UserNotificationTypeenum: -1NEW_VIDEO_FROM_SUBSCRIPTION -2NEW_COMMENT_ON_MY_VIDEO -3NEW_ABUSE_FOR_MODERATORS -4BLACKLIST_ON_MY_VIDEO -5UNBLACKLIST_ON_MY_VIDEO -6MY_VIDEO_PUBLISHED -7MY_VIDEO_IMPORT_SUCCESS -8MY_VIDEO_IMPORT_ERROR -9NEW_USER_REGISTRATION -10NEW_FOLLOW -11COMMENT_MENTION -12VIDEO_AUTO_BLACKLIST_FOR_MODERATORS -13NEW_INSTANCE_FOLLOWER -14AUTO_INSTANCE_FOLLOWING -15ABUSE_STATE_CHANGE -16ABUSE_NEW_MESSAGE -17NEW_PLUGIN_VERSION -18NEW_PEERTUBE_VERSION -19MY_VIDEO_STUDIO_EDITION_FINISHED -20NEW_USER_REGISTRATION_REQUEST -21NEW_LIVE_FROM_SUBSCRIPTION - read
- video
- videoImport
- comment
- videoAbuse
- videoBlacklist
- account
- actorFollow
- createdAt
- updatedAt
- Annotations
-
- @BuiltValue.new()
Constructors
- Notification([void updates(NotificationBuilder b)])
-
factory
Properties
- account → ActorInfo?
-
no setter
- actorFollow → NotificationActorFollow?
-
no setter
- comment → NotificationComment?
-
no setter
- createdAt → DateTime?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
no setter
- read → bool?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int?
-
Notification type, following the
UserNotificationTypeenum: -1NEW_VIDEO_FROM_SUBSCRIPTION -2NEW_COMMENT_ON_MY_VIDEO -3NEW_ABUSE_FOR_MODERATORS -4BLACKLIST_ON_MY_VIDEO -5UNBLACKLIST_ON_MY_VIDEO -6MY_VIDEO_PUBLISHED -7MY_VIDEO_IMPORT_SUCCESS -8MY_VIDEO_IMPORT_ERROR -9NEW_USER_REGISTRATION -10NEW_FOLLOW -11COMMENT_MENTION -12VIDEO_AUTO_BLACKLIST_FOR_MODERATORS -13NEW_INSTANCE_FOLLOWER -14AUTO_INSTANCE_FOLLOWING -15ABUSE_STATE_CHANGE -16ABUSE_NEW_MESSAGE -17NEW_PLUGIN_VERSION -18NEW_PEERTUBE_VERSION -19MY_VIDEO_STUDIO_EDITION_FINISHED -20NEW_USER_REGISTRATION_REQUEST -21NEW_LIVE_FROM_SUBSCRIPTIONno setter - updatedAt → DateTime?
-
no setter
- video → NotificationVideo?
-
no setter
- videoAbuse → NotificationVideoAbuse?
-
no setter
- videoBlacklist → NotificationVideoAbuse?
-
no setter
- videoImport → NotificationVideoImport?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(NotificationBuilder)) → Notification -
Rebuilds the instance.
inherited
-
toBuilder(
) → NotificationBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
Notification> -
no setter