NotificationActorFollow class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- NotificationActorFollow([void updates(NotificationActorFollowBuilder b)])
-
factory
Properties
- follower → ActorInfo?
-
no setter
- following → NotificationActorFollowFollowing?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → NotificationActorFollowStateEnum?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(NotificationActorFollowBuilder)) → NotificationActorFollow -
Rebuilds the instance.
inherited
-
toBuilder(
) → NotificationActorFollowBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
NotificationActorFollow> -
no setter