UserRegistrationUser class abstract
If the registration has been accepted, this is a partial user object created by the registration
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- UserRegistrationUser([void updates(UserRegistrationUserBuilder b)])
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserRegistrationUserBuilder)) → UserRegistrationUser -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserRegistrationUserBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserRegistrationUser> -
no setter